@@ -6,6 +6,7 @@ from edc_vitals.model_mixins import (
     SimpleBloodPressureModelMixin,
     WeightHeightBmiModelMixin,
 )
+from edc_vitals.models.fields import TemperatureField
 
 
 class BloodPressure(BloodPressureModelMixin, models.Model):
@@ -16,6 +17,14 @@ class SimpleBloodPressure(SimpleBloodPressureModelMixin, models.Model):
     pass
 
 
+class Temperature(models.Model):
+
+    temperature = TemperatureField(
+        null=True,
+        blank=True,
+    )
+
+
 class WeightHeightBmi(WeightHeightBmiModelMixin, models.Model):
 
     report_datetime = models.DateTimeField(default=get_utcnow)
